@@ -4,8 +4,8 @@
     Delete JAWS AVRO schemas from the Schema Registry
 """
 
-import os
 import json
+import os
 import pkgutil
 import traceback
 
@@ -14,16 +14,16 @@ from confluent_kafka.schema_registry import SchemaRegistryClient, SchemaRegistry
 scriptpath = os.path.dirname(os.path.realpath(__file__))
 projectpath = scriptpath + '/../../'
 
-sr_conf = {'url':  os.environ.get('SCHEMA_REGISTRY', 'http://localhost:8081')}
+sr_conf = {'url': os.environ.get('SCHEMA_REGISTRY', 'http://localhost:8081')}
 client = SchemaRegistryClient(sr_conf)
 
 
 def __process(record):
     try:
         versions = client.delete_subject(record['subject'], True)
-        print('Successfully deleted {}; versions: {}'.format(record['subject'], versions))
+        print(f'Successfully deleted {record["subject"]}; versions: {versions}')
     except SchemaRegistryError:
-        print('Unable to delete: {}'.format(record['subject']))
+        print(f'Unable to delete: {record["subject"]}')
         traceback.print_exc()
 
 
