@@ -4,8 +4,8 @@
     Describe JAWS AVRO schemas in to Schema Registry
 """
 
-import os
 import json
+import os
 import pkgutil
 
 from confluent_kafka.schema_registry import SchemaRegistryClient
@@ -15,7 +15,7 @@ def describe_schemas() -> None:
     """
         Describe JAWS AVRO schemas in to Schema Registry
     """
-    sr_conf = {'url':  os.environ.get('SCHEMA_REGISTRY', 'http://localhost:8081')}
+    sr_conf = {'url': os.environ.get('SCHEMA_REGISTRY', 'http://localhost:8081')}
     client = SchemaRegistryClient(sr_conf)
 
     conf = pkgutil.get_data("jaws_libp", "avro/schema-registry.json")
@@ -24,8 +24,8 @@ def describe_schemas() -> None:
 
     lookup = {}
 
-    for r in records:
-        lookup[r['subject']] = r['file']
+    for record in records:
+        lookup[record['subject']] = record['file']
 
     subjects = client.get_subjects()
 
@@ -39,10 +39,10 @@ def describe_schemas() -> None:
 
         path = "/tmp/" + filename
         os.makedirs(os.path.dirname(path), exist_ok=True)
-        with open(path, "w") as text_file:
+        with open(path, "w", encoding="utf-8") as text_file:
             print(json.dumps(json.loads(registered.schema.schema_str), indent=4), file=text_file)
 
-        print("ID: {}, Subject: {}, Version: {}, File: {}".format(registered.schema_id, registered.subject, registered.version, path))
+        print(f"ID: {registered.schema_id}, Subject: {registered.subject}, Version: {registered.version}, File: {path}")
 
 
 if __name__ == "__main__":
